@@ -19,6 +19,6 @@ Provides location to maintain version information.
 @author: Kenneth J. Pronovici <pronovic@ieee.org>
 """
 
-VERSION     = "0.8.1"
-DATE        = "04 Apr 2006"
+VERSION     = "0.8.2"
+DATE        = "13 Jun 2007"
 
